@@ -1,6 +1,4 @@
 #' Barplot interactive plot.
-#' @param colorVar (optional) String with color variable.
-#' @param colorLab String with label for \code{colorVar}.
 #' @param barmode String with type of barplot, either:
 #' 'group' or 'stack' (see parameter in \code{\link[plotly]{layout}}).
 #' @param textVar (optional) String with a text variable,
@@ -29,6 +27,7 @@ barplotClinData <- function(
 	# general plot:
 	titleExtra = NULL,
 	title = paste(paste(yLab, "vs", xLab, titleExtra), collapse = "<br>"),
+	caption = NULL, subtitle = NULL,
 	labelVars = NULL,
 	# interactivity:
 	width = NULL, height = NULL,
@@ -43,6 +42,10 @@ barplotClinData <- function(
 
 	# store input parameter values for further use
 	plotArgs <- c(as.list(environment()))
+	
+	# drop unused factor levels as plotly default
+	if(is.factor(data[, xVar]))
+		data[, xVar] <- droplevels(data[, xVar])
 
 	idVars <- c(xVar, colorVar)
 	data$idEl <- interaction(data[, idVars, drop = FALSE])
@@ -65,13 +68,17 @@ barplotClinData <- function(
 	)
 	
 	# get plot dim
-	dimPlot <- getSizePlotClinData(
+	dimPlot <- getSizePlot(
 		width = width, height = height,
-		legend = !is.null(colorVar),
-		legendPosition = "bottom"
+		includeLegend = !is.null(colorVar),
+		legendPosition = "top",
+		title = title,
+		caption = caption,
+		subtitle = subtitle,
+		xLab = xLab
 	)
-	width <- unname(dimPlot["width"])
-	height <- unname(dimPlot["height"])
+	width <- dimPlot[["width"]]
+	height <- dimPlot[["height"]]
 	
 	if(is.null(colorPalette)){
 		colorPaletteOpt <- getOption("clinDataReview.colors")
@@ -102,11 +109,10 @@ barplotClinData <- function(
 	)
 	
 	## layout option
-	
-	xaxisArgs <- list(title = xLab, tickangle = 45)
+	xaxisArgs <- list(tickangle = 45)
 	
 	# in case x-var is not nested within color variable
-	# when elements are selected in the legend legend selection,
+	# when elements are selected in the legend,
 	# corresponding elements are not filtered in the x-axis (bar is only removed)
 	# this is a fix:
 	if(!is.null(colorVar) && !is.numeric(data[, xVar]) && barmode == "stack"){
@@ -134,19 +140,22 @@ barplotClinData <- function(
 			
 		}
 	}
-	pl <- pl %>% layout(
-		title = title,
-		xaxis = xaxisArgs,
-		yaxis = list(title = yLab), 
-		barmode = barmode
-	)
 	
-	pl <- pl %>% layout(legend = 
-		list(
-			orientation = "h",
-			x = 0.5, xanchor = "center",
-			y = 1
-		)
+	pl <- layoutClinData(
+		p = pl,
+		xLab = xLab,
+		yLab = yLab,
+		title = title,
+		caption = caption, 
+		subtitle = subtitle,
+		includeLegend = !is.null(colorVar),
+		legendPosition = "top",
+		legend = list(title = list(text = colorLab)),
+		width = width,
+		height = height,
+		# extra params passed to plotly::layout
+		xaxis = xaxisArgs,
+		barmode = barmode
 	)
 		
 	# specific formatting for clinical data
