@@ -1,18 +1,18 @@
-context("Visualization of count data for clinical data")
+context("Visualize clinical count data")
 
 library(plotly)
 library(jsonlite)
 
-test_that("dataset with missing parent value returns an error", {
+test_that("An error is generated if a dataset with incorrect parent-child structure is provided for the count visualization", {
 			
 	data <- data.frame(
-		varParent = c("A", "A", "B"),
-		varChild = c("a", "b", "c"),
+		parent = c("A", "A", "B"),
+		child = c("a", "b", "c"),
 		n = seq.int(3)
 	)
 	expect_error(
 		plotCountClinData(data, 
-			vars = c("varParent", "varChild"), 
+			vars = c("parent", "child"), 
 			valueVar = "n"
 		),
 		"Missing parent value"
@@ -20,16 +20,16 @@ test_that("dataset with missing parent value returns an error", {
 	
 })
 	
-test_that("parent variable(s) being not the sum of their children is flagged", {				
+test_that("A warning is generated when parent variable(s) are smaller than the sum of their children", {				
 	
 	data <- data.frame(
-		varParent = c("A", "A", "A", "B", "B"),
-		varChild = c("a", "b", "Total", "c", "Total"),
+		parent = c("A", "A", "A", "B", "B"),
+		child = c("a", "b", "Total", "c", "Total"),
 		n = c(1, 2, 1, 2, 1)
 	)
 	expect_warning(
 		plotCountClinData(data, 
-			vars = c("varParent", "varChild"), 
+			vars = c("parent", "child"), 
 			valueVar = "n"
 		),
 		"are smaller than the sum of their children"
@@ -37,18 +37,16 @@ test_that("parent variable(s) being not the sum of their children is flagged", {
 	
 })
 
-test_that("creation of count visualization for one specified parent variable is successful", {				
+test_that("Counts with one specified parent variable are correctly visualized", {				
 			
 	data <- data.frame(
-		varParent = c("A", "A", "A", "B", "B"),
-		varChild = c("a", "b", "Total", "c", "Total"),
+		parent = c("A", "A", "A", "B", "B"),
+		child = c("a", "b", "Total", "c", "Total"),
 		n = c(1, 2, 3, 5, 5)
 	)
-	expect_silent(
-		pl <- plotCountClinData(data, 
-			vars = c("varParent", "varChild"), 
-			valueVar = "n"
-		)
+	pl <- plotCountClinData(data, 
+		vars = c("parent", "child"), 
+		valueVar = "n"
 	)
 	expect_s3_class(pl, "plotly")
 	plotData <- as.data.frame(plotly_data(pl))
@@ -57,7 +55,11 @@ test_that("creation of count visualization for one specified parent variable is
 	plotDataInput <- plotData[, colnames(data)]
 	plotDataInputOrder <- plotDataInput[do.call(order, plotData), ]
 	dataOrder <- data[do.call(order, data), ]
-	expect_equal(plotDataInputOrder, dataOrder, check.attributes = FALSE)
+	expect_equal(
+		object = plotDataInputOrder, 
+		expected = dataOrder, 
+		check.attributes = FALSE
+	)
 		
 	# check extraction of hierarchical data
 	dataHierar <- data.frame(
@@ -70,22 +72,24 @@ test_that("creation of count visualization for one specified parent variable is
 	dataHierarOrder <- dataHierar[do.call(order, dataHierar), ]
 	plotDataInternal <- plotData[, colnames(dataHierar)]
 	plotDataInternalOrder <- plotDataInternal[do.call(order, plotDataInternal), ]
-	expect_equal(plotDataInternalOrder, dataHierarOrder, check.attributes = FALSE)
+	expect_equal(
+		object = plotDataInternalOrder, 
+		expected = dataHierarOrder, 
+		check.attributes = FALSE
+	)
 			
 })
 
-test_that("child and parent variables can contain the same element", {
+test_that("Counts with child and parent elements with the same element are correctly visualized", {
 			
 	data <- data.frame(
-		varParent = c("A", "A", "A", "B", "B"),
-		varChild = c("A", "b", "Total", "c", "Total"),
+		parent = c("A", "A", "A", "B", "B"),
+		child = c("A", "b", "Total", "c", "Total"),
 		n = c(1, 2, 3, 5, 5)
 	)
-	expect_silent(
-		pl <- plotCountClinData(data, 
-			vars = c("varParent", "varChild"), 
-			valueVar = "n"
-		)
+	pl <- plotCountClinData(data, 
+		vars = c("parent", "child"), 
+		valueVar = "n"
 	)
 	
 	plotData <- as.data.frame(plotly_data(pl))
@@ -102,25 +106,27 @@ test_that("child and parent variables can contain the same element", {
 	dataHierarOrder <- dataHierar[do.call(order, dataHierar), ]
 	plotData <- plotData[,  colnames(dataHierar)]
 	plotDataOrder <- plotData[do.call(order, plotData), ]
-	expect_equal(plotDataOrder, dataHierarOrder, check.attributes = FALSE)
+	expect_equal(
+		object = plotDataOrder, 
+		expected = dataHierarOrder, 
+		check.attributes = FALSE
+	)
 	
 })
 
 
-test_that("specification of color categorical variable is successful", {				
+test_that("A categorical color variable is correctly set in the count visualization", {				
 			
 	data <- data.frame(
-		varParent = c("A", "A", "A", "B", "B"),
-		varChild = c("a", "b", "Total", "c", "Total"),
+		parent = c("A", "A", "A", "B", "B"),
+		child = c("a", "b", "Total", "c", "Total"),
 		n = c(1, 2, 3, 5, 5)
 	)
-	expect_silent(
-		pl <- plotCountClinData(
-			data, 
-			vars = c("varParent", "varChild"), 
-			valueVar = "n",
-			colorVar = "varParent"
-		)
+	pl <- plotCountClinData(
+		data, 
+		vars = c("parent", "child"), 
+		valueVar = "n",
+		colorVar = "parent"
 	)
 	
 	plotJson <- plotly_json(pl, jsonedit = FALSE)
@@ -133,38 +139,36 @@ test_that("specification of color categorical variable is successful", {
 	
 })
 
-test_that("specification of color numerical variable with color range is successful", {				
+test_that("A numeric color numerical variable with color range is correctly set in the count visualization", {				
 			
 	set.seed(123)
 	data <- data.frame(
-		varParent = sample(LETTERS[seq.int(6)], 100, replace = TRUE),
-		varChild = sample(letters[seq.int(6)], 100, replace = TRUE),
+		parent = sample(LETTERS[seq.int(6)], 100, replace = TRUE),
+		child = sample(letters[seq.int(6)], 100, replace = TRUE),
 		n = seq.int(100)
 	)
-	data <- data[!duplicated(data[, c("varParent", "varChild")]), ]
-	totalN <- with(data, tapply(n, varParent, sum))
+	data <- data[!duplicated(data[, c("parent", "child")]), ]
+	totalN <- with(data, tapply(n, parent, sum))
 	data <- rbind(data,
 		data.frame(
-			varParent = names(totalN),
-			varChild = "Total",
+			parent = names(totalN),
+			child = "Total",
 			n = totalN
 		)
 	)
 	
-	expect_silent(
-		pl <- plotCountClinData(
-			data, 
-			vars = c("varParent", "varChild"), 
-			valueVar = "n",
-			colorVar = "n"
-		)
+	pl <- plotCountClinData(
+		data, 
+		vars = c("parent", "child"), 
+		valueVar = "n",
+		colorVar = "n"
 	)
 	
 	plData <- plotly_build(pl)$x$data[[1]]
 	colors <- plData$marker$colors
 	ids <- plData$ids
 	
-	data$ids <- with(data, paste(varParent, varChild, sep = "-"))
+	data$ids <- with(data, paste(parent, child, sep = "-"))
 	data$ids <- sub("-Total", "", data$ids)
 	colorsData <- data[match(ids, data$ids), "n"]
 	statPerColor <- tapply(colorsData, colors, range)
@@ -177,22 +181,20 @@ test_that("specification of color numerical variable with color range is success
 	
 })
 
-test_that("table is created with count visualization", {				
+test_that("An interactive table is correctly included in the count visualization", {				
 			
 	data <- data.frame(
-		varParent = c("A", "A", "A", "B", "B"),
-		varChild = c("a", "b", "Total", "c", "Total"),
+		parent = c("A", "A", "A", "B", "B"),
+		child = c("a", "b", "Total", "c", "Total"),
 		n = c(1, 2, 3, 5, 5),
 		stringsAsFactors = TRUE
 	)
 
-	expect_silent(
-		res <- plotCountClinData(
-			data, 
-			vars = c("varParent", "varChild"), 
-			valueVar = "n",
-			table = TRUE
-		)
+	res <- plotCountClinData(
+		data, 
+		vars = c("parent", "child"), 
+		valueVar = "n",
+		table = TRUE
 	)
 	table <- res$table
 	expect_s3_class(table, "datatables")
@@ -204,29 +206,30 @@ test_that("table is created with count visualization", {
 		hierarID = c("A-a", "A-b", "A", "B-c", "B"),
 		stringsAsFactors = TRUE
 	)
-	expect_equal(sort(colnames(tableInput)), sort(colnames(tableData)))
+	expect_setequal(
+		object = colnames(tableInput), 
+		expected = colnames(tableData)
+	)
 	
 	tableData <- tableData[, colnames(tableInput)]
 	
 	expect_equal(
-		tableInput[do.call(order, tableInput), ], 
-		tableData[do.call(order, tableData), ]
+		object = tableInput[do.call(order, tableInput), ], 
+		expected = tableData[do.call(order, tableData), ]
 	)
 			
 })
 
-test_that("overall total is correctly included", {				
+test_that("The overall total is correctly included in the count visualization", {				
 			
 	data <- data.frame(
-		varParent = c("A", "A", "A", "B", "B", "Total"),
-		varChild = c("a", "b", "Total", "c", "Total", "Total"),
+		parent = c("A", "A", "A", "B", "B", "Total"),
+		child = c("a", "b", "Total", "c", "Total", "Total"),
 		n = c(1, 2, 3, 4, 4, 7)
 	)
-	expect_silent(
-		pl <- plotCountClinData(data, 
-			vars = c("varParent", "varChild"), 
-			valueVar = "n"
-		)
+	pl <- plotCountClinData(data, 
+		vars = c("parent", "child"), 
+		valueVar = "n"
 	)
 	expect_s3_class(pl, "plotly")
 	plotData <- as.data.frame(plotly_data(pl))
@@ -235,7 +238,11 @@ test_that("overall total is correctly included", {
 	plotDataInput <- plotData[, colnames(data)]
 	plotDataInputOrder <- plotDataInput[do.call(order, plotData), ]
 	dataOrder <- data[do.call(order, data), ]
-	expect_equal(plotDataInputOrder, dataOrder, check.attributes = FALSE)
+	expect_equal(
+		object = plotDataInputOrder, 
+		expected = dataOrder, 
+		check.attributes = FALSE
+	)
 			
 	# check extraction of hierarchical data
 	dataHierar <- data.frame(
@@ -248,7 +255,10 @@ test_that("overall total is correctly included", {
 	dataHierarOrder <- dataHierar[do.call(order, dataHierar), ]
 	plotDataInternal <- plotData[, colnames(dataHierar)]
 	plotDataInternalOrder <- plotDataInternal[do.call(order, plotDataInternal), ]
-	expect_equal(plotDataInternalOrder, dataHierarOrder, check.attributes = FALSE)
+	expect_equal(
+		object = plotDataInternalOrder, 
+		expected = dataHierarOrder, 
+		check.attributes = FALSE
+	)
 			
-})
-
+})
\ No newline at end of file
